--AH:ScriptId=bf8f9c94-ad03-490c-be35-dee731982bcc;2991
CREATE TABLE [Executions]
(
	[Execution_Id] INT IDENTITY(1,1) NOT NULL,
	[Start_Date] DATETIME NOT NULL,
	[End_Date] DATETIME NULL,
	[ExecutionStatus_Code] CHAR(1) NOT NULL,
	[ExecutionRunState_Code] CHAR(1) NOT NULL,
	[ExecutionMode_Code] CHAR(1) NOT NULL,
	[CreatedBy_User_Name] USERNAME NOT NULL,
	[CreatedOn_Date] DATETIME NOT NULL,
	[CanceledBy_User_Name] USERNAME NULL,
	[CanceledOn_Date] DATETIME NULL,

	CONSTRAINT [PK__Executions]
		PRIMARY KEY ([Execution_Id]),

	CONSTRAINT [CK__Executions__ExecutionStatus_Code]
		CHECK ([ExecutionStatus_Code] IN ('S', 'W', 'E')),

	CONSTRAINT [CK__Executions__ExecutionRunState_Code]
		CHECK ([ExecutionRunState_Code] IN ('P', 'X', 'C')),

	CONSTRAINT [CK__Executions__ExecutionMode_Code]
		CHECK ([ExecutionMode_Code] IN ('A', 'B', 'C', 'D', 'E'))
)

SET IDENTITY_INSERT [Executions] ON
GO

INSERT INTO [Executions]
(
	[Execution_Id],
	[Start_Date],
	[End_Date],
	[ExecutionStatus_Code],
	[ExecutionRunState_Code],
	[ExecutionMode_Code],
	[CreatedBy_User_Name],
	[CreatedOn_Date],
	[CanceledBy_User_Name],
	[CanceledOn_Date]
)
SELECT [Execution_Id],
       [ExecutionStart_Date],
	   [ExecutionEnded_Date],
	   CASE WHEN [ExecutionStatus_Name] = 'Succeeded' AND [WarningLogEntry_Indicator] = 'N' THEN 'S'
	        WHEN [ExecutionStatus_Name] = 'Succeeded' AND [WarningLogEntry_Indicator] = 'Y' THEN 'W'
			WHEN [ExecutionStatus_Name] = 'Pending' THEN 'S'
			ELSE 'E'
	   END,
	   CASE WHEN [ExecutionStatus_Name] = 'Pending' THEN 'P'
	        ELSE 'C'
	   END,
	   'A',
	   COALESCE([CreatedBy_User_Name], 'UNKNOWN'),
	   COALESCE([CreatedOn_Date], [ExecutionStart_Date]),
	   [CanceledBy_User_Name],
	   [CanceledOn_Date]
  FROM [BuildExecutions]

DBCC CHECKIDENT ('Executions') WITH NO_INFOMSGS
GO

SET IDENTITY_INSERT [Executions] OFF
GO

ALTER TABLE [BuildExecutions]
	ADD [Execution_Id2] INT NULL

GO

UPDATE [BuildExecutions]
   SET [Execution_Id2] = [Execution_Id]
GO

ALTER TABLE [BuildExecutions]
	ALTER COLUMN [Execution_Id2] INT NOT NULL

ALTER TABLE [BuildArtifacts]
	DROP CONSTRAINT [FK__BuildArtifacts__BuildExecutions]

ALTER TABLE [VariableDefinitions]
	DROP CONSTRAINT [FK__VariableDefinitions__BuildExecutions]

ALTER TABLE [ChangeControlPerformances]
	DROP CONSTRAINT [FK__ChangeControlPerformances__BuildExecutions]

ALTER TABLE [ConfigurationFileDeployments]
	DROP CONSTRAINT [FK__ConfigurationFileDeployments__BuildExecutions]

ALTER TABLE [BuildOutputs]
	DROP CONSTRAINT [FK__BuildOutputs__BuildExecutions]

ALTER TABLE [ManualActionsInProgress]
	DROP CONSTRAINT [FK__ManualActionsInProgress__BuildExecutions]

ALTER TABLE [ScopedExecutionLogs]
	DROP CONSTRAINT [FK__ScopedExecutionLogs__Executions]

ALTER TABLE [BuildExecution_DeploymentPlans]
	DROP CONSTRAINT [FK__BuildExecution_DeploymentPlans__BuildExecutions]

ALTER TABLE [DatabaseChangeScriptExecutions]
	DROP CONSTRAINT [FK__DatabaseChangeScriptExecutions__BuildExecutions]

ALTER TABLE [BuildExecutions]
	DROP CONSTRAINT [FK__BuildExecutions__BuildExecutions]	

ALTER TABLE [BuildExecutions]
	DROP CONSTRAINT [PK__BuildExecutions]	

GO

DROP INDEX [IX__BuildExecutions__ExecutionStatus_Name] ON [BuildExecutions]

ALTER TABLE [BuildExecutions]
	DROP CONSTRAINT [CK__BuildExecution_Plans__ExecutionStatus_Name_Domain]

GO

ALTER TABLE [BuildExecutions]
	DROP COLUMN [Execution_Id]
GO

EXEC sp_rename 'BuildExecutions.Execution_Id2', 'Execution_Id', 'COLUMN'
GO

ALTER TABLE [BuildExecutions]
	ADD CONSTRAINT [PK__BuildExecutions]
		PRIMARY KEY CLUSTERED ([Execution_Id])

ALTER TABLE [BuildExecutions]
	ADD CONSTRAINT [FK__BuildExecutions__Executions]
		FOREIGN KEY ([Execution_Id])
		REFERENCES [Executions] ([Execution_Id]) ON DELETE CASCADE
GO

ALTER TABLE [BuildArtifacts]
	ADD CONSTRAINT [FK__BuildArtifacts__Executions]
		FOREIGN KEY ([Execution_Id])
		REFERENCES [Executions] ([Execution_Id]) ON DELETE CASCADE

ALTER TABLE [VariableDefinitions]
	ADD CONSTRAINT [FK__VariableDefinitions__Executions]
		FOREIGN KEY ([Execution_Id])
		REFERENCES [Executions] ([Execution_Id]) ON DELETE CASCADE

ALTER TABLE [ChangeControlPerformances]
	DROP COLUMN [Execution_Id]

ALTER TABLE [ConfigurationFileDeployments]
	ADD CONSTRAINT [FK__ConfigurationFileDeployments__Executions]
		FOREIGN KEY ([Execution_Id])
		REFERENCES [Executions] ([Execution_Id]) ON DELETE SET NULL

ALTER TABLE [BuildOutputs]
	ADD CONSTRAINT [FK__BuildOutputs__Executions]
		FOREIGN KEY ([Execution_Id])
		REFERENCES [Executions] ([Execution_Id]) ON DELETE CASCADE

ALTER TABLE [ManualActionsInProgress]
	ADD CONSTRAINT [FK__ManualActionsInProgress__Executions]
		FOREIGN KEY ([Execution_Id])
		REFERENCES [Executions] ([Execution_Id]) ON DELETE CASCADE

ALTER TABLE [ScopedExecutionLogs]
	ADD CONSTRAINT [FK__ScopedExecutionLogs__Executions]
		FOREIGN KEY ([Execution_Id])
		REFERENCES [Executions] ([Execution_Id]) ON DELETE CASCADE

ALTER TABLE [BuildExecution_DeploymentPlans]
	ADD CONSTRAINT [FK__BuildExecution_DeploymentPlans__BuildExecutions]
		FOREIGN KEY ([Execution_Id])
		REFERENCES [BuildExecutions] ([Execution_Id]) ON DELETE CASCADE

ALTER TABLE [DatabaseChangeScriptExecutions]
	ADD CONSTRAINT [FK__DatabaseChangeScriptExecutions__Executions]
		FOREIGN KEY ([Execution_Id])
		REFERENCES [Executions] ([Execution_Id]) ON DELETE SET NULL

ALTER TABLE [BuildExecutions]
	ADD CONSTRAINT [FK__BuildExecutions__BuildExecutions]
		FOREIGN KEY ([LastActionReexecutionOf_Execution_Id])
		REFERENCES [BuildExecutions] ([Execution_Id])

ALTER TABLE [BuildExecutions]
	DROP COLUMN [ExecutionStart_Date]

ALTER TABLE [BuildExecutions]
	DROP COLUMN [ExecutionStatus_Name]

ALTER TABLE [BuildExecutions]
	DROP COLUMN [CanceledBy_User_Name]

ALTER TABLE [BuildExecutions]
	DROP COLUMN [CanceledOn_Date]

ALTER TABLE [BuildExecutions]
	DROP COLUMN [CreatedBy_User_Name]

ALTER TABLE [BuildExecutions]
	DROP COLUMN [CreatedOn_Date]

ALTER TABLE [BuildExecutions]
	DROP COLUMN [ExecutionEnded_Date]

ALTER TABLE [BuildExecutions]
	DROP COLUMN [WarningLogEntry_Indicator]