EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'BuildSchedules_CreateOrUpdateSCMTriggered',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Schedule_Id',
    /* Description_Text        */ 'Creates a source control triggered automated build based on the specified parameters, or updates an existing one if one with a given ID already exists.',
    /* Remarks_Text            */ NULL
GO

IF OBJECT_ID('[BuildSchedules_CreateOrUpdateSCMTriggered]') IS NOT NULL DROP PROCEDURE [BuildSchedules_CreateOrUpdateSCMTriggered]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [BuildSchedules_CreateOrUpdateSCMTriggered]
(
	@Schedule_Id INT = NULL OUT,
	@Schedule_Name VARCHAR(100),
	@Application_Id INT,
	@SourceControl_Path_Name VARCHAR(250),
	@SourceControl_Provider_Id INT,
	@SourceControl_QuietPeriod_Minutes INT,
	@ReleaseFilter_ReleaseType_Code CHAR(1),
	@ReleaseFilter_Pipeline_Id INT,
    @ReleaseFilter_Release_Number RELEASENUMBER,
	@Active_Indicator YNINDICATOR
) AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @Schedule_Id IS NULL
	BEGIN
		INSERT INTO [dbo].[BuildSchedules]
			([Schedule_Name]
			,[Application_Id]
			,[Active_Indicator]
			,[Schedule_Type]
			,[CreatedBy_User_Name]
			,[CreatedOn_Date]
			,[ModifiedBy_User_Name]
			,[ModifiedOn_Date]
			,[SourceControl_Path_Name]
			,[SourceControl_Provider_Id]
			,[SourceControl_QuietPeriod_Minutes]
			,[ReleaseFilter_ReleaseType_Code]
			,[ReleaseFilter_Pipeline_Id]
            ,[ReleaseFilter_Release_Number])
		VALUES
			(@Schedule_Name
			,@Application_Id
			,@Active_Indicator
			,'SCM Triggered'
			,dbo.Session_GetUserName()
			,GETUTCDATE()
			,dbo.Session_GetUserName()
			,GETUTCDATE()
			,@SourceControl_Path_Name
			,@SourceControl_Provider_Id
			,@SourceControl_QuietPeriod_Minutes
			,@ReleaseFilter_ReleaseType_Code
			,@ReleaseFilter_Pipeline_Id
            ,@ReleaseFilter_Release_Number)

		SET @Schedule_Id = SCOPE_IDENTITY()

		EXEC [Events_RaiseEvent] 'BSHNEW',@Application_Id,@Schedule_Id

	END
	ELSE
	BEGIN
		
		DECLARE @Schedule_Type VARCHAR(15)
		SELECT @Schedule_Type = [Schedule_Type] 
		  FROM [BuildSchedules]
		 WHERE [Schedule_Id] = @Schedule_Id
		
		IF @@ROWCOUNT=0 RAISERROR('BuildSchedule #%i does not exist.',16,1,@Schedule_Id) 
		IF @Schedule_Type <> 'SCM Triggered' RAISERROR('Existing BuildSchedule #%i is not an SCM Triggered schedule, it is %s.', 16, 1, @Schedule_Id, @Schedule_Type)
	
		UPDATE [dbo].[BuildSchedules]
		   SET [Schedule_Name] = @Schedule_Name
			  ,[Active_Indicator] = @Active_Indicator
			  ,[ModifiedBy_User_Name] = dbo.Session_GetUserName()
			  ,[ModifiedOn_Date] = GETUTCDATE()
			  ,[SourceControl_Path_Name] = @SourceControl_Path_Name
			  ,[SourceControl_Provider_Id] = @SourceControl_Provider_Id
			  ,[SourceControl_QuietPeriod_Minutes] = @SourceControl_QuietPeriod_Minutes
			  ,[ReleaseFilter_ReleaseType_Code] = @ReleaseFilter_ReleaseType_Code
			  ,[ReleaseFilter_Pipeline_Id] = @ReleaseFilter_Pipeline_Id
              ,[ReleaseFilter_Release_Number] = @ReleaseFilter_Release_Number
		 WHERE [Schedule_Id] = @Schedule_Id
		

		EXEC [Events_RaiseEvent] 'BSHMOD',@Application_Id,@Schedule_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [BuildSchedules_CreateOrUpdateSCMTriggered] TO [BuildMasterUser_Role]
