EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'LegacyExecutions_SetVariableValue',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates, updates, or deletes an execution time variable value.'
GO

IF OBJECT_ID('[LegacyExecutions_SetVariableValue]') IS NOT NULL DROP PROCEDURE [LegacyExecutions_SetVariableValue]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [LegacyExecutions_SetVariableValue]
(
	@BuildExecution_ActionGroupAction_Id INT,
	@Variable_Name VARCHAR(50),
	@Value_Text VARCHAR(MAX)
)
AS
BEGIN

	SET NOCOUNT ON
	
BEGIN TRY
	BEGIN TRANSACTION
	
	DECLARE @ExecutionStatus_Name VARCHAR(10)
	
	SELECT @ExecutionStatus_Name = BE.[ExecutionStatus_Name]
	  FROM [BuildExecution_ActionGroupActions] BEAGA
	       INNER JOIN [BuildExecution_DeploymentPlans] BEDP
	               ON BEAGA.[BuildExecution_DeploymentPlan_Id] = BEDP.[BuildExecution_DeploymentPlan_Id]
	       INNER JOIN [BuildExecutions_Extended] BE
	               ON BE.[Execution_Id] = BEDP.[Execution_Id]
	 WHERE BEAGA.[BuildExecution_ActionGroupAction_Id] = @BuildExecution_ActionGroupAction_Id

	IF @ExecutionStatus_Name <> 'Pending' AND @ExecutionStatus_Name <> 'Executing'
		RAISERROR('Variables cannot be set on a %s execution.', 16, 1, @ExecutionStatus_Name)

	IF EXISTS(SELECT *
	            FROM [BuildExecution_ActionGroupActionVariableValues]
	           WHERE [BuildExecution_ActionGroupAction_Id] = @BuildExecution_ActionGroupAction_Id
	             AND [Variable_Name] = @Variable_Name)
	BEGIN
		IF @Value_Text IS NULL
		BEGIN
			DELETE [BuildExecution_ActionGroupActionVariableValues]
             WHERE [BuildExecution_ActionGroupAction_Id] = @BuildExecution_ActionGroupAction_Id
               AND [Variable_Name] = @Variable_Name
		END
		ELSE
		BEGIN
			UPDATE [BuildExecution_ActionGroupActionVariableValues]
			   SET [Value_Text] = @Value_Text
	         WHERE [BuildExecution_ActionGroupAction_Id] = @BuildExecution_ActionGroupAction_Id
	           AND [Variable_Name] = @Variable_Name
	    END
	END
	ELSE IF @Value_Text IS NOT NULL
	BEGIN
		INSERT INTO [BuildExecution_ActionGroupActionVariableValues]
		(
			[BuildExecution_ActionGroupAction_Id],
			[Variable_Name],
			[Value_Text]
		)
		VALUES
		(
			@BuildExecution_ActionGroupAction_Id,
			@Variable_Name,
			@Value_Text
		)
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [LegacyExecutions_SetVariableValue] TO [BuildMasterUser_Role]
