EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Plans_ChangeActionGroupDeploymentPlan',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Moves a plan action group to the final position of a different deployment plan.'
GO


IF OBJECT_ID('[Plans_ChangeActionGroupDeploymentPlan]') IS NOT NULL DROP PROCEDURE [Plans_ChangeActionGroupDeploymentPlan]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Plans_ChangeActionGroupDeploymentPlan]
(
	@DeploymentPlanActionGroup_Id INT,
	@New_DeploymentPlan_Id INT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY

	BEGIN TRANSACTION

    DECLARE @DeploymentPlanActionGroup_Sequence INT
    DECLARE @ActionGroup_Id INT
    DECLARE @DeploymentPlan_Id INT
	
	SELECT @ActionGroup_Id = [ActionGroup_Id],
	       @DeploymentPlanActionGroup_Sequence = [DeploymentPlanActionGroup_Sequence],
	       @DeploymentPlan_Id = [DeploymentPlan_Id]
	  FROM [DeploymentPlanActionGroups]
	 WHERE [DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id

    DECLARE @Last_DeploymentPlanActionGroup_Sequence INT
    SELECT @Last_DeploymentPlanActionGroup_Sequence = MAX([DeploymentPlanActionGroup_Sequence])
      FROM [DeploymentPlanActionGroups]
     WHERE [DeploymentPlan_Id] = @DeploymentPlan_Id

    -- move action group to the end of the sequence in the current environment to appease trigger
    EXEC [Plans_ResequenceActionGroup] @DeploymentPlanActionGroup_Id, @Last_DeploymentPlanActionGroup_Sequence

    -- move action group to the end of the sequence of action groups in the new environment
    UPDATE [DeploymentPlanActionGroups]
	   SET [DeploymentPlanActionGroup_Sequence] = (SELECT COALESCE(MAX([DeploymentPlanActionGroup_Sequence]), 0) 
	                                                 FROM [DeploymentPlanActionGroups] 
	                                                WHERE [DeploymentPlan_Id] = @New_DeploymentPlan_Id) + 1,
	       [DeploymentPlan_Id] = @New_DeploymentPlan_Id
	 WHERE [DeploymentPlanActionGroup_Id] = @DeploymentPlanActionGroup_Id

 	-- disable reexecution for anything that used either plan
	UPDATE [BuildExecutions]
	   SET [ReexecutionState_Xml] = NULL
	 WHERE [Execution_Id] IN (SELECT BEDP.[Execution_Id]
	                            FROM [BuildExecution_DeploymentPlans] BEDP
	                           WHERE BEDP.[Original_DeploymentPlan_Id] = @DeploymentPlan_Id
	                              OR BEDP.[Original_DeploymentPlan_Id] = @New_DeploymentPlan_Id)

	EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @DeploymentPlan_Id
	EXEC [Events_RaiseEvent] 'PLNMOD', NULL, @New_DeploymentPlan_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Plans_ChangeActionGroupDeploymentPlan] TO [BuildMasterUser_Role]