EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Providers_CreateOrUpdateProvider',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Provider_Id',
    /* Description_Text        */ 'Creates a new provider or updates an existing one.'
GO


IF OBJECT_ID('[Providers_CreateOrUpdateProvider]') IS NOT NULL DROP PROCEDURE [Providers_CreateOrUpdateProvider]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Providers_CreateOrUpdateProvider]
(
	@Provider_Id INT = NULL OUT,
	@ProviderType_Code CHAR(1),
	@ExecuteOn_Server_Id INT,
	@Provider_Name VARCHAR(50),
	@Provider_Description VARCHAR(100),
	@Provider_Configuration VARCHAR(MAX),
	@Internal_Indicator YNINDICATOR	 = 'N'
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    -- BitChecker recipe checks for the existence of a provider before attempting to create one, but
    -- Providers_GetProviders doesn't return internal providers - so without a new SDK it can never know
    -- if an example provider was created already. This hack will ensure the recipe can be run more than once.
    IF (@Provider_Id IS NULL AND @Internal_Indicator = 'Y')
    BEGIN

        SELECT @Provider_Id = [Provider_Id]
          FROM [Providers]
         WHERE [Provider_Name] = @Provider_Name
           AND [ProviderType_Code] = @ProviderType_Code

            IF (@Provider_Id IS NOT NULL)
            BEGIN
                COMMIT
                RETURN
            END

    END

	IF (@Provider_Id IS NULL) 
	BEGIN

		IF @ProviderType_Code <> 'B' AND EXISTS(SELECT * FROM [Providers] WHERE [Provider_Name] = @Provider_Name AND [ProviderType_Code] = @ProviderType_Code)
			RAISERROR('A provider with that name already exists.', 16, 1)

		INSERT INTO [Providers]
            (
				[ProviderType_Code],
				[Provider_Name],
				[ExecuteOn_Server_Id],
				[Provider_Description],
				[Provider_Configuration],
				[CreatedBy_User_Name],
				[CreatedOn_Date],
				[ModifiedBy_User_Name],
				[ModifiedOn_Date],
				[Internal_Indicator]
			)
		VALUES
            (
				@ProviderType_Code,
				@Provider_Name,
				@ExecuteOn_Server_Id,
				@Provider_Description,
				@Provider_Configuration,
				dbo.Session_GetUserName(),
				GETUTCDATE(),
				dbo.Session_GetUserName(),
				GETUTCDATE(),
				@Internal_Indicator
			)
		SET @Provider_Id = SCOPE_IDENTITY()

		IF @ProviderType_Code = 'B' /*DataBase */
			EXEC [Events_RaiseEvent] 'DBSNEW', NULL, @Provider_Id
		ELSE
			EXEC [Events_RaiseEvent] 'PVDNEW', NULL, @Provider_Id
	END
	ELSE
	BEGIN
		IF EXISTS(SELECT * FROM [Providers]
		           WHERE [Provider_Id] = @Provider_Id
		             AND [Internal_Indicator] = 'Y')
		    RAISERROR('A provider marked as internal may not be edited.', 16, 1)

		IF @ProviderType_Code <> 'B' AND EXISTS(SELECT * FROM [Providers] WHERE [Provider_Name] = @Provider_Name AND [Provider_Id] <> @Provider_Id AND [ProviderType_Code] = @ProviderType_Code)
			RAISERROR('A provider with that name already exists.', 16, 1)

		UPDATE [Providers]
		   SET [ProviderType_Code] = @ProviderType_Code,
		       [Provider_Name] = @Provider_Name,
			   [ExecuteOn_Server_Id] = @ExecuteOn_Server_Id,
			   [Provider_Description] = @Provider_Description,
			   [Provider_Configuration] = @Provider_Configuration,
			   [ModifiedBy_User_Name] = dbo.Session_GetUserName(),
			   [ModifiedOn_Date] = GETUTCDATE()
		 WHERE [Provider_Id] = @Provider_Id

		IF @ProviderType_Code = 'B' /*DataBase */
			EXEC [Events_RaiseEvent] 'DBSMOD', NULL, @Provider_Id
		ELSE
			EXEC [Events_RaiseEvent] 'PVDMOD', NULL, @Provider_Id
	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [Providers_CreateOrUpdateProvider] TO [BuildMasterUser_Role]