EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'RetentionPolicies_GetArtifactsToPurge',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'DataTable',
    /* DataTableNames_Csv      */ 'BuildArtifacts_Slim',
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Gets the artifacts for the specified retention policy that can be purged.'
GO

IF OBJECT_ID('[RetentionPolicies_GetArtifactsToPurge]') IS NOT NULL DROP PROCEDURE [RetentionPolicies_GetArtifactsToPurge]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [RetentionPolicies_GetArtifactsToPurge]
(
	@RetentionPolicy_Id INT
)
AS
BEGIN

	SET NOCOUNT ON

    DECLARE @ArtifactsMatchingFilter_Count INT
    DECLARE @ArtifactsToDelete_Count INT
	DECLARE @DeployedReleasesOnly_Indicator YNINDICATOR
    DECLARE @RejectedBuildsOnly_Indicator YNINDICATOR
    DECLARE @Retention_Count INT
    DECLARE @AlwaysRetainAfter_Date DATETIME
	DECLARE @Application_Id INT
	DECLARE @ApplicationGroup_Id INT
    DECLARE @Pipeline_Id INT
    
    SELECT @DeployedReleasesOnly_Indicator = [PurgeIn_OnlyDeployedReleases_Indicator],
           @RejectedBuildsOnly_Indicator = [PurgeIn_OnlyRejectedBuilds_Indicator],
           @Retention_Count = [Retention_Count],
           @Application_Id = [PurgeIn_Application_Id],
           @ApplicationGroup_Id = [PurgeIn_ApplicationGroup_Id],
           @Pipeline_Id = [PurgeIn_Pipeline_Id],
           @AlwaysRetainAfter_Date = DATEADD(DAY, -1 * [Retention_Days_Count], GETUTCDATE())
      FROM [RetentionPolicies]
     WHERE [RetentionPolicy_Id] = @RetentionPolicy_Id

    IF @Retention_Count IS NOT NULL
    BEGIN

        SELECT @ArtifactsMatchingFilter_Count = COUNT(*) 
                                      FROM [BuildArtifacts_Slim] BA
	                            INNER JOIN [Applications] A
		                                ON A.[Application_Id] = BA.[Application_Id]
		                        INNER JOIN [Releases] R
		                                ON R.[Release_Id] = BA.[Release_Id]
	                        WHERE (@Application_Id IS NULL OR BA.[Application_Id] = @Application_Id)
	                          AND (@ApplicationGroup_Id IS NULL OR A.[ApplicationGroup_Id] = @ApplicationGroup_Id)
                              AND (@Pipeline_Id IS NULL OR R.[Pipeline_Id] = @Pipeline_Id)
	                          AND (@RejectedBuildsOnly_Indicator = 'N' OR BA.[BuildStatus_Name] = 'Rejected')
	                          AND (@DeployedReleasesOnly_Indicator = 'N' OR R.[ReleaseStatus_Name] = 'Deployed')

        SET @ArtifactsToDelete_Count = @ArtifactsMatchingFilter_Count - @Retention_Count
        
        IF (@ArtifactsToDelete_Count < 1)
            RETURN

        SET ROWCOUNT @ArtifactsToDelete_Count

    END

	SELECT *
	    FROM [BuildArtifacts_Slim] BA
	        INNER JOIN [Applications] A
		            ON A.[Application_Id] = BA.[Application_Id]
		    INNER JOIN [Releases] R
		             ON R.[Release_Id] = BA.[Release_Id]
	    WHERE (@Application_Id IS NULL OR BA.[Application_Id] = @Application_Id)
	    AND (@ApplicationGroup_Id IS NULL OR A.[ApplicationGroup_Id] = @ApplicationGroup_Id)
        AND (@Pipeline_Id IS NULL OR R.[Pipeline_Id] = @Pipeline_Id)
	    AND (@RejectedBuildsOnly_Indicator = 'N' OR BA.[BuildStatus_Name] = 'Rejected')
	    AND (@DeployedReleasesOnly_Indicator = 'N' OR R.[ReleaseStatus_Name] = 'Deployed')
	    AND (@AlwaysRetainAfter_Date IS NULL OR BA.[Created_Date] < @AlwaysRetainAfter_Date)
        ORDER BY [Created_Date]

END
GO

GRANT EXECUTE ON [RetentionPolicies_GetArtifactsToPurge] TO [BuildMasterUser_Role]