EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'ScriptAssets_CreateOrUpdateScript',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'ScriptAsset_Id',
    /* Description_Text        */ 'Creates a new script or updates an existing one.'
GO

IF OBJECT_ID('[ScriptAssets_CreateOrUpdateScript]') IS NOT NULL DROP PROCEDURE [ScriptAssets_CreateOrUpdateScript]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [ScriptAssets_CreateOrUpdateScript]
(
	@ScriptAsset_Name VARCHAR(200),
	@Application_Id INT,
	@Script_Text VARBINARY(MAX),
	@ModifiedBy_User_Name USERNAME = NULL,
	@ModifiedOn_Date DATETIME = NULL,
	@ScriptAsset_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF @ScriptAsset_Id IS NULL
	BEGIN

		INSERT INTO [ScriptAssets]
		(
			[ScriptAsset_Name],
			[Application_Id],
			[Script_Text],
			[ModifiedBy_User_Name],
			[ModifiedOn_Date]
		)
		VALUES
		(
			@ScriptAsset_Name,
			@Application_Id,
			@Script_Text,
			COALESCE(@ModifiedBy_User_Name, dbo.Session_GetUserName()),
			COALESCE(@ModifiedOn_Date, GETUTCDATE())
		)

		SET @ScriptAsset_Id = SCOPE_IDENTITY()

	END
	ELSE
	BEGIN

		UPDATE [ScriptAssets]
		   SET [ScriptAsset_Name] = @ScriptAsset_Name,
		       [Application_Id] = @Application_Id,
			   [Script_Text] = @Script_Text,
		       [ModifiedBy_User_Name] = COALESCE(@ModifiedBy_User_Name, dbo.Session_GetUserName()),
		       [ModifiedOn_Date] = COALESCE(@ModifiedOn_Date, GETUTCDATE())
		 WHERE [ScriptAsset_Id] = @ScriptAsset_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [ScriptAssets_CreateOrUpdateScript] TO [BuildMasterUser_Role]