EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'Scripts_CreateVersion',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'Version_Number',
    /* Description_Text        */ 'Creates a new version of a script.'
GO


IF OBJECT_ID('[Scripts_CreateVersion]') IS NOT NULL DROP PROCEDURE [Scripts_CreateVersion]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Scripts_CreateVersion]
(
	@Version_Number INT OUT,
	@Script_Id INT,
	@Script_Bytes VARBINARY(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	SET @Version_Number = (SELECT MAX([Version_Number])
	                         FROM [ScriptVersions]
	                        WHERE [Script_Id] = @Script_Id)

	DECLARE @Latest_Bytes VARBINARY(MAX)
	SET @Latest_Bytes = (SELECT [Script_Bytes]
	                       FROM [ScriptVersions]
	                      WHERE [Script_Id] = @Script_Id
	                        AND [Version_Number] = @Version_Number)

	--Do not insert a copy of the most recent version
	IF @Latest_Bytes IS NULL OR @Latest_Bytes <> @Script_Bytes
	BEGIN

		SET @Version_Number = COALESCE(@Version_Number, 0) + 1

		INSERT INTO [ScriptVersions]
		(
			[Script_Id],
			[Version_Number],
			[Script_Bytes],
			[CreatedBy_User_Name],
			[CreatedOn_Date]
		)
		VALUES
		(
			@Script_Id,
			@Version_Number,
			@Script_Bytes,
			dbo.Session_GetUserName(),
			GETUTCDATE()
		)

		UPDATE [Scripts]
		   SET [ModifiedBy_User_Name] = dbo.Session_GetUserName(),
			   [ModifiedOn_Date] = GETUTCDATE()
		 WHERE [Script_Id] = @Script_Id

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [Scripts_CreateVersion] TO [BuildMasterUser_Role]