EXEC [dbo].[__BuildMaster_AddStoredProcInfo]
    /* StoredProc_Name         */ 'VariableValueRenderers_CreateOrUpdateVariableValueRenderer',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ 'VariableValueRenderer_Id',
    /* Description_Text        */ 'Creates a new variable value renderer, or updates an existing one.'
GO

IF OBJECT_ID('[VariableValueRenderers_CreateOrUpdateVariableValueRenderer]') IS NOT NULL DROP PROCEDURE [VariableValueRenderers_CreateOrUpdateVariableValueRenderer]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [VariableValueRenderers_CreateOrUpdateVariableValueRenderer]
(
	@Variable_Name VARCHAR(50),
	@Render_Text NVARCHAR(MAX),
	@Application_Id INT = NULL,
	@ApplicationGroup_Id INT = NULL,
	@VariableValueRenderer_Id INT = NULL OUT
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

    DECLARE @Existing_Renderer_Id INT

    SELECT @Existing_Renderer_Id = [VariableValueRenderer_Id] 
      FROM [VariableValueRenderers]
     WHERE [VariableValueRenderer_Id] = @VariableValueRenderer_Id

	IF @Existing_Renderer_Id IS NOT NULL
	BEGIN

		UPDATE [VariableValueRenderers]
		   SET [Variable_Name] = @Variable_Name,
			   [Render_Text] = @Render_Text,
			   [Application_Id] = @Application_Id,
			   [ApplicationGroup_Id] = @ApplicationGroup_Id
		 WHERE [VariableValueRenderer_Id] = @Existing_Renderer_Id

         SET @VariableValueRenderer_Id = @Existing_Renderer_Id

	END
	ELSE
	BEGIN

		INSERT INTO [VariableValueRenderers]
		(
			[Variable_Name],
			[Render_Text],
			[Application_Id],
			[ApplicationGroup_Id]
		)
		VALUES
		(
			@Variable_Name,
			@Render_Text,
			@Application_Id,
			@ApplicationGroup_Id
		)

        SET @VariableValueRenderer_Id = SCOPE_IDENTITY()

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [VariableValueRenderers_CreateOrUpdateVariableValueRenderer] TO [BuildMasterUser_Role]
